pub struct PartneredSmallParcelDataInput {
    pub package_list: Option<Vec<PartneredSmallParcelPackageInput>>,
    pub carrier_name: Option<String>,
}
PartneredSmallParcelDataInput : Information that is required by an Amazon-partnered carrier to ship a Small Parcel inbound shipment.

Fields

package_list: Option<Vec<PartneredSmallParcelPackageInput>>

A list of dimensions and weight information for packages.

carrier_name: Option<String>

The Amazon-partnered carrier to use for the inbound shipment. CarrierName values in France (FR), Italy (IT), Spain (ES), the United Kingdom (UK), and the United States (US): UNITED_PARCEL_SERVICE_INC.
CarrierName values in Germany (DE): DHL_STANDARD,UNITED_PARCEL_SERVICE_INC.
Default: UNITED_PARCEL_SERVICE_INC.

Implementations

Information that is required by an Amazon-partnered carrier to ship a Small Parcel inbound shipment.